@@ -978,19 +978,25 @@ async def toZoneDisplayName(clients, destinationZoneDisplay):
     destinationZone = ''
 
     # if specific world command was used, create a new list of zones only within the specified world
-    if any(destinationZoneDisplay.startswith(abbreviation + ' ') for abbreviation in worldAbbreviations):
-        abbrIndex = worldAbbreviations.index(abbreviation)
-        worldLines = []
-        world = worldList.index(abbrIndex)
+    for abbreviation in worldAbbreviations:
+        if destinationZoneDisplay.startswith(abbreviation + ' '):
+            abbrIndex = worldAbbreviations.index(abbreviation)
+            worldLines = []
+            world = worldList[abbrIndex]
 
-        for q, s in enumerate(lines):
-            split = s.split(';')
-            if split[1] == world:
-                worldLines.append(s)
+            for q, s in enumerate(lines):
+                split = s.split(';')
+                if split[0] == world:
+                    worldLines.append(s)
 
-            lines = iter(worldLines)
+                lines = iter(worldLines)
+
+            # for some reason this code runs even with the if statement evaluates to false... unless there is a print statement here
+            # blame python idk what to tell you
+            destinationZoneDisplay = destinationZoneDisplay.split(abbreviation + ' ')[1]
+
+    # if any(destinationZoneDisplay.startswith(abbreviation + ' ') for abbreviation in worldAbbreviations):
 
-        destinationZoneDisplay = destinationZoneDisplay.split(abbreviation + ' ')[1]
 
     for q, s in enumerate(lines):
         s = s.split(';')
